import { StringMap } from "./Support";
export declare enum ErrorMessage {
    InternalError = "Internal error: ${message}",
    JSONParseError = "Syntax error in ${description} JSON ${address}: ${message}",
    ReadError = "Cannot read from file or URL ${fileOrURL}: ${message}",
    UnicodeHighSurrogateWithoutLowSurrogate = "Malformed unicode: High surrogate not followed by low surrogate",
    ArrayIsInvalidJSONSchema = "An array is not a valid JSON Schema",
    NullIsInvalidJSONSchema = "null is not a valid JSON Schema",
    RefMustBeString = "$ref must be a string",
    AdditionalTypesForbidRequired = "Can't have non-specified required properties but forbidden additionalTypes",
    NoTypeSpecified = "JSON Schema must specify at least one type",
    FalseSchemaNotSupported = "Schema \"false\" is not supported",
    RefWithFragmentNotAllowed = "Ref URI with fragment is not allowed: ${ref}",
    InvalidJSONSchemaType = "Value of type ${type} is not valid JSON Schema",
    RequiredMustBeStringOrStringArray = "`required` must be string or array of strings, but is ${actual}",
    RequiredElementMustBeString = "`required` must contain only strings, but it has ${element}",
    TypeMustBeStringOrStringArray = "`type` must be string or array of strings, but is ${actual}",
    TypeElementMustBeString = "`type` must contain only strings, but it has ${element}",
    ArrayItemsMustBeStringOrArray = "Array items must be an array or an object, but is ${actual}",
    IDMustHaveAddress = "$id doesn't have an address: ${id}",
    WrongAccessorEntryArrayLength = "Accessor entry array must have the same number of entries as the ${operation}",
    SetOperationCasesIsNotArray = "${operation} cases must be an array, but is ${cases}",
    CannotFetchSchema = "Cannot fetch schema at address ${address}",
    MoreThanOneUnionMemberName = "More than one name given for union member: ${names}",
    NoGraphQLQueriesDefined = "GraphQL file doesn't have any queries defined.",
    UnknownSourceLanguage = "Unknown source language ${lang}",
    UnknownOutputLanguage = "Unknown output language ${lang}",
    NeedExactlyOneSchema = "Must have exactly one schema for ${name}",
    MoreThanOneSchemaGiven = "More than one schema given for ${name}",
    NoGraphQLQueryGiven = "Please specify at least one GraphQL query as input",
    NoGraphQLSchemaInDir = "No GraphQL schema in ${dir}",
    MoreThanOneGraphQLSchemaInDir = "More than one GraphQL schema in ${dir}",
    SourceLangMustBeGraphQL = "If a GraphQL schema is specified, the source language must be GraphQL",
    GraphQLSchemaNeeded = "Please specify a GraphQL schema with --graphql-schema or --graphql-introspect",
    InputFileDoesNotExist = "Input file ${filename} does not exist",
    CannotMixJSONWithOtherSamples = "Cannot mix JSON samples with JSON Schems, GraphQL, or TypeScript in input subdirectory ${dir}",
    CannotMixNonJSONInputs = "Cannot mix JSON Schema, GraphQL, and TypeScript in an input subdirectory ${dir}",
    UnknownDebugOption = "Unknown debug option ${option}",
    InvalidSchemaTopLevelRefs = "Schema top level refs must be `/definitions/`, but is `${actual}`",
    NoLanguageOrExtension = "Please specify a language (--lang) or an output file extension",
    CLIOptionParsingFailed = "Option parsing failed: ${message}",
    NoForwardDeclarableTypeInCycle = "Cannot resolve cycle because it doesn't contain types that can be forward declared",
    TypeAttributesNotPropagated = "Type attributes for ${count} types were not carried over to the new graph",
    NoEmptyUnions = "Trying to make an empty union - do you have an impossible type in your schema?",
    UnknownRendererOptionValue = "Unknown value ${value} for option ${name}",
    TypeScriptCompilerError = "TypeScript error: ${message}",
}
export declare class QuickTypeError extends Error {
    readonly errorMessage: ErrorMessage;
    readonly properties: StringMap;
    constructor(errorMessage: ErrorMessage, userMessage: string, properties: StringMap);
}
export declare function messageError(message: ErrorMessage): never;
export declare function messageError(message: ErrorMessage, properties: StringMap): never;
export declare function messageAssert(assertion: boolean, message: ErrorMessage): void;
export declare function messageAssert(assertion: boolean, message: ErrorMessage, properties: StringMap): void;
